@@ -40,19 +40,24 @@ DigitalClockWdg::DigitalClockWdg(QGraphicsScene *scene)
     m_gLine->setPos(-size().width(),-size().height());
     m_gCity = m_scene->addText("");
     m_gCity->setPos(-size().width(),-size().height());
+    m_gLine2 = m_scene->addLine(0,0,0,0);
+    m_gLine2->setPos(-size().width(),-size().height());
+    m_gDate = m_scene->addText("");
+    m_gDate->setPos(-size().width(),-size().height());
 
     setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     setCacheMode(QGraphicsView::CacheNone);
     setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
 
     m_gProxy = m_scene->addWidget(clk1);
+//    m_x = x();
+//    m_y = y();
 }
 
 void DigitalClockWdg::setId(QString &aAppletId)
 {
     m_aplletId = aAppletId;
     loadSettings();
-
 //showSettingsDialog();    //!!
 //    initClock();
 }
@@ -69,28 +74,56 @@ int DigitalClockWdg::drawCityName()
     QFontMetrics fm(fnt);
     int textSize = fm.height();
     m_wCity = fm.width(m_cityName);
-    int y = m_sc_y + textSize + 2;
+    int y = m_sc_y + textSize;
     m_scene->removeItem(m_gLine);
     m_scene->removeItem(m_gCity);
     m_gLine = m_scene->addLine(0,0,size().width(),0, pen);
-    m_gLine->setPos(m_sc_x,y);
+    m_gLine->setPos(m_sc_x,y + 4);
     m_gCity = m_scene->addText(m_cityName,fnt);
     m_gCity->setPos(m_sc_x + (size().width()-m_wCity)/2,m_sc_y);
     return textSize + 4;
 }
 
+int DigitalClockWdg::drawDate()
+{
+    // calc font + line
+    // get pen color
+    QFont fnt = font();
+    QPalette qp = palette();
+    QPen pen(qp.color(QPalette::Text));
+    fnt.setPointSize(m_dateSize);
+    QFontMetrics fm(fnt);
+    int textSize = fm.height();
+    m_wDate = fm.width(m_dateString);
+    int y = m_sc_y + textSize;
+    m_scene->removeItem(m_gLine2);
+    m_scene->removeItem(m_gDate);
+    m_gLine2 = m_scene->addLine(0,0,size().width(),0, pen);
+    m_gLine2->setPos(m_sc_x,y+2);
+    m_gDate = m_scene->addText(m_dateString,fnt);
+    m_gDate->setPos(m_sc_x + (size().width()-m_wDate)/2,m_sc_y - 4);
+    m_gDate->setDefaultTextColor(m_digitColor);
+    return textSize + 4;
+}
+
+
 void DigitalClockWdg::initClock()
 {
     delete clk1;
+    m_hCity = 0;
+    m_hDate = 0;
 //    m_scene->removeItem(m_gProxy);
     QTime tm = calcTime();
+    m_dateString = calcDate();
     QString tStr = tm.toString(m_timeFormat);
     QSize asize;
+    // enabled Show city
     if (!m_showCity)
     {
         asize = size();
         m_gLine->setVisible(false);
         m_gCity->setVisible(false);
+        m_hCity = 0;
     }
     else
     {
@@ -100,8 +133,24 @@ void DigitalClockWdg::initClock()
         m_hCity = drawCityName();
         asize.setHeight(asize.height()-m_hCity);
         m_sc_y = m_sc_y + m_hCity; // move Clock down
-        // todo calc size for city
     }
+
+    // enabled Show city
+    if (!m_showDate)
+    {
+        m_gLine2->setVisible(false);
+        m_gDate->setVisible(false);
+        m_hDate = 0;
+    }
+    else
+    {
+        m_gLine2->setVisible(true);
+        m_gDate->setVisible(true);
+        m_hDate = drawDate();
+        asize.setHeight(asize.height()-m_hDate);
+        m_sc_y = m_sc_y + m_hDate; // move Clock down
+    }
+
     if (m_lcd)
     {
         clk1 = new LcdClock(m_digitColor, tStr, asize);
@@ -117,10 +166,31 @@ void DigitalClockWdg::initClock()
     m_gProxy->setPos(m_sc_x,m_sc_y);
 }
 
+QString DigitalClockWdg::calcDate()
+{
+    //TODO need to call initClock when date changes
+//    QString dtstr(tr("Date: "));
+    QDateTime dt = QDateTime::currentDateTime();
+    if (m_tzOffset != -50000)
+    {
+        QDateTime udt = dt.toUTC();
+        dt = udt.addSecs(m_tzOffset);
+    }
+    if (m_fullDateFormat)
+//        return dt.date().toString(Qt::DefaultLocaleLongDate);
+        return dt.date().toString(Qt::TextDate);
+//        return dtstr + dt.date().toString(Qt::DefaultLocaleLongDate);
+    else
+        return dt.date().toString(Qt::DefaultLocaleShortDate);
+//        return dtstr + dt.date().toString(Qt::DefaultLocaleShortDate);
+}
+
 QTime DigitalClockWdg::calcTime()
 {
     if (m_tzOffset == -50000)
+    {
         return QTime::currentTime();
+    }
     else
     {
         QDateTime dt = QDateTime::currentDateTime();
@@ -132,9 +202,19 @@ QTime DigitalClockWdg::calcTime()
 
 void DigitalClockWdg::showTime()
 {
-    //TODO update clock
     QTime tt = calcTime();
 
+    //TODO: not the best blace to check date changes - takes too many reosurces
+    if (m_showDate)
+    {
+        QString newDate = calcDate();
+        if (newDate.compare(m_dateString))
+        {
+            initClock();
+            return;
+        }
+    }
+
 //    QTime time = QTime::currentTime();
     QString text = tt.toString(m_timeFormat);
     if (m_blinking1)
@@ -170,6 +250,12 @@ void DigitalClockWdg::loadSettings()
     bool blinking = dclocksettings::getInstance().isBlinking(m_aplletId);
     m_openclock = dclocksettings::getInstance().isOpenClockEnabled(m_aplletId);
     m_showCity = dclocksettings::getInstance().isShowCityEnabled(m_aplletId);
+    m_corner = dclocksettings::getInstance().getCornerNumber(m_aplletId);
+
+    m_showDate =  dclocksettings::getInstance().isShowDateEnabled(m_aplletId);
+    m_fullDateFormat = dclocksettings::getInstance().isFullDateFormat(m_aplletId);
+    m_dateSize = dclocksettings::getInstance().getDateSize(m_aplletId);
+
 #else
     m_digitColor = QColor(Qt::blue);
     bool showSeconds = true;
@@ -301,22 +387,6 @@ void DigitalClockWdg::showClock()
 #endif
 }
 
-//void DigitalClockWdg::paintEvent(QPaintEvent *event)
-//{
-    /*Q_UNUSED(event);
-    QPainter p(this);
-    p.setOpacity(m_transparency);
-    p.setBrush(Qt::SolidPattern);
-//    QBrush qb = p.background();
-//    QColor qc = qb.color();
-//    qc.setAlpha(50);
-//    qb.setColor(qc);
-//    p.setBackground(qb);
-    p.setPen(Qt::NoPen);
-    p.drawRect(rect());*/
-//}
-
-
 void DigitalClockWdg::enableRotationMonitor(bool aRotatable)
 {
 #if  defined(Q_WS_MAEMO_5)
@@ -344,10 +414,10 @@ void DigitalClockWdg::enableRotationMonitor(bool aRotatable)
 void DigitalClockWdg::orientationChanged(QString aMessage)
 {
 #if  defined(Q_WS_MAEMO_5)
-//    int x = geometry().x();
-//    int y = geometry().y();
-//    int wd = size().width();
-//    int hg = size().height();
+    int wd = size().width();
+    int hg = size().height();
+    int x = pos().x();
+    int y = pos().y();
     if ((aMessage == QLatin1String(MCE_ORIENTATION_PORTRAIT)) && !m_rotate)
     {
         setTransform(QTransform()
@@ -355,37 +425,46 @@ void DigitalClockWdg::orientationChanged(QString aMessage)
                .rotate(270, Qt::ZAxis)
                .translate(-size().width() / 2, -size().height() / 2));
         m_rotate = true;
-
-        if (!m_showCity)
+        switch (m_corner)
         {
-            m_gProxy->resize(QSize(m_gProxy->size().height(),m_gProxy->size().width()));
-            m_gProxy->setPos(m_sc_y,m_sc_x);
-        }
-        else
-        {
-            m_gCity->setPos(m_sc_y-m_hCity + (size().height()-m_wCity)/2,m_sc_x);
-            m_gLine->setPos(m_sc_y-m_hCity,m_sc_x+m_hCity-2);
-            m_gProxy->resize(QSize(size().height(),size().width()-m_hCity));
-            m_gProxy->setPos(m_sc_y-m_hCity,m_sc_x+m_hCity);
+        case 1:
+            break;
+        case 2:
+            x = x + wd - hg;
+            break;
+        case 3:
+            x = x + wd - hg;
+            y = y - wd + hg;
+            break;
+        case 4:
+            y = y - wd + hg;
+            break;
         }
+        move(x,y);
+        resize(QSize(hg,wd));
         update();
     }
     else if (m_rotate)
     {
         setTransform(QTransform());
         m_rotate = false;
-        if (!m_showCity)
+        switch (m_corner)
         {
-            m_gProxy->resize(QSize(m_gProxy->size().height(),m_gProxy->size().width()));
-            m_gProxy->setPos(m_sc_x,m_sc_y);
-        }
-        else
-        {
-            m_gCity->setPos(m_sc_x + (size().width()-m_wCity)/2,m_sc_y-m_hCity);
-            m_gLine->setPos(m_sc_x,m_sc_y-2);
-            m_gProxy->resize(QSize(size().width(),size().height()-m_hCity));
-            m_gProxy->setPos(m_sc_x,m_sc_y);
+        case 1:
+            break;
+        case 2:
+            x = x + wd - hg;
+            break;
+        case 3:
+            x = x + wd - hg;
+            y = y - wd + hg;
+            break;
+        case 4:
+            y = y - wd + hg;
+            break;
         }
+        move(x,y);
+        resize(QSize(hg,wd));
         update();
     }
 #else
