@@ -14,7 +14,7 @@
 #include "ui_settingsdialog.h"
 #include "dclocksettings.h"
 
-#define STR_VERSION "0.4.1"
+#define STR_VERSION "0.4.3"
 #define STR_CRLF "<br>"
 #define STR_QT_VERSION "<b>Qt 4.6.2</b>"
 #define STR_COPYRIGHT "Copyright (c) 2010 Avis"
@@ -29,7 +29,7 @@ SettingsDialog::SettingsDialog(QString &aAppletId, QWidget *parent) :
     buildFontList();
     ui->chbBold->setEnabled(false);
     ui->chbItalic->setEnabled(false);
-    fillTZlist();
+    fillTZlist(ui->cbTZ);
 
     rotateToggle(false);
     loadSettings();
@@ -144,6 +144,10 @@ void SettingsDialog::dumpSettings() const
     if (ui->rbBL->isChecked())
         aCorner = 4;
     dclocksettings::getInstance().setCornerNumber(m_appletId,aCorner);
+
+    dclocksettings::getInstance().setShowDateEnabled(m_appletId,ui->cbShowDate->isChecked());
+    dclocksettings::getInstance().setFullDateFormat(m_appletId,ui->cbFullDate->isChecked());
+    dclocksettings::getInstance().setDateSize(m_appletId,ui->spinDateSize->value());
 }
 
 int SettingsDialog::calcOffset() const
@@ -173,6 +177,10 @@ void SettingsDialog::loadSettings()
     ui->chbShowCity->setChecked(dclocksettings::getInstance().isShowCityEnabled(m_appletId));
     ui->spinCitySize->setValue(dclocksettings::getInstance().getCitySize(m_appletId));
 
+    ui->cbShowDate->setChecked(dclocksettings::getInstance().isShowDateEnabled(m_appletId));
+    ui->cbFullDate->setChecked(dclocksettings::getInstance().isFullDateFormat(m_appletId));
+    ui->spinDateSize->setValue(dclocksettings::getInstance().getDateSize(m_appletId));
+
     int aCorner = dclocksettings::getInstance().getCornerNumber(m_appletId);
     switch (aCorner)
     {
@@ -279,7 +287,7 @@ void SettingsDialog::fontChanged(int aIndex)
     }
 }
 
-void SettingsDialog::fillTZlist()
+void SettingsDialog::fillTZlist(QComboBox* &aBox)
 {
 #if  defined(Q_WS_MAEMO_5)
     int ret = 0;
@@ -288,7 +296,7 @@ void SettingsDialog::fillTZlist()
 
     QString defTZ = QString::fromUtf8(current_tz);
 
-    ui->cbTZ->clear();
+    aBox->clear();
     //    int k = 0; //
     Cityinfo **cities = cityinfo_get_all();
     for (int i = 0; cities && cities[i]; ++i) {
@@ -311,14 +319,14 @@ void SettingsDialog::fillTZlist()
             timeoffset = QString("%2, %1, (UTC %3)").arg(name).arg(country).arg(sign+QString::number(-offset/3600));
         else
             timeoffset = QString("%2, %1, (UTC %3:%4)").arg(name).arg(country).arg(sign+QString::number(-offset/3600)).arg("30");
-        ui->cbTZ->addItem(timeoffset,-offset);
+        aBox->addItem(timeoffset,-offset);
         if (zone == defTZ)
             defTZ = timeoffset;
     }
     cityinfo_free_all(cities);
-    ui->cbTZ->model()->sort(0);
-    int k = ui->cbTZ->findText(defTZ);
-    ui->cbTZ->setCurrentIndex(k);
+    aBox->model()->sort(0);
+    int k = aBox->findText(defTZ);
+    aBox->setCurrentIndex(k);
 #endif
 }
 
