@@ -2,6 +2,7 @@
 #define SETTINGSDIALOG_H
 
 #include <QDialog>
+#include <QComboBox>
 #include <QPushButton>
 
 namespace Ui {
@@ -25,13 +26,14 @@ public slots:
 private slots:
     void showAbout();
     void showQtAbout();
+    void rotateToggle(bool);
 
 private:
     void loadSettings();
     void buildFontList();
 //    void fillCbTZ();
     int calcOffset() const;
-    void fillTZlist();
+    void fillTZlist(QComboBox* &aBox);
 
 private:
     QString m_appletId;
